==> mars-0.9.2.tar.gz: mars-0.9.2/include/mpu/mars/mars_task_barrier.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_TASK_BARRIER_H
#define MARS_TASK_BARRIER_H

/**
 * \file
 * \ingroup group_mars_task_barrier
 * \brief [MPU] MARS Task Barrier API
 */

#if defined(__cplusplus)
extern "C" {
#endif

#include "mars/mars_task_barrier_types.h"

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Initializes a task barrier.
 *
 * \param[out] barrier_ea	- ea of barrier instance to initialize
 * \param[in] total		- number of notifies before barrier released
 * \return
 *	MARS_SUCCESS		- successfully initialized barrier
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_PARAMS	- total exceeds allowed limit
 */
int mars_task_barrier_initialize(uint64_t barrier_ea, uint32_t total);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Notifies a task barrier. (Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- successfully notified barrier
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_LIMIT	- maximum number of tasks already waiting
 * \n	MARS_ERROR_FORMAT	- no context save area specified
 */
int mars_task_barrier_notify(uint64_t barrier_ea);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Notifies a task barrier. (Non-Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- successfully notified barrier
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_BUSY		- previous waits have not completed
 */
int mars_task_barrier_try_notify(uint64_t barrier_ea);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Waits on a task barrier. (Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- barrier is released
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_LIMIT	- maximum number of tasks already waiting
 * \n	MARS_ERROR_FORMAT	- no context save area specified
 */
int mars_task_barrier_wait(uint64_t barrier_ea);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Waits on a task barrier. (Non-Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- barrier is released
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_BUSY		- not all notifications arrived yet
 */
int mars_task_barrier_try_wait(uint64_t barrier_ea);

#if defined(__cplusplus)
}
#endif

#endif

==> mars-08.06.26.tar.gz: mars-08.06.26/include/mpu/mars/mars_task_barrier.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified 
 *  version of the Library in object code or as an executable provided 
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete 
 *   corresponding machine-readable source code for the modified version 
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer 
 *   for a complete machine-readable copy of the corresponding source 
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_TASK_BARRIER_H
#define MARS_TASK_BARRIER_H

/**
 * \file
 * \ingroup group_mars_task_barrier
 * \brief [MPU] MARS Task Barrier API
 */

#if defined(__cplusplus)
extern "C" {
#endif

#include "mars/mars_task_barrier_types.h"

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Initializes a task barrier.
 *
 * \param[out] barrier_ea	- ea of barrier instance to initialize
 * \param[in] total		- number of notifies before barrier released
 * \return
 *	MARS_SUCCESS		- successfully initialized barrier
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_PARAMS	- total exceeds allowed limit
 */
int mars_task_barrier_initialize(uint64_t barrier_ea, uint32_t total);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Notifies a task barrier.
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- successfully notified barrier
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_LIMIT	- total notifications already received
 */
int mars_task_barrier_notify(uint64_t barrier_ea);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Waits on a task barrier. (Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- barrier is released
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_LIMIT	- maximum number of tasks already waiting
 * \n	MARS_ERROR_FORMAT	- no context save area specified
 */
int mars_task_barrier_wait(uint64_t barrier_ea);

/**
 * \ingroup group_mars_task_barrier
 * \brief [MPU] Waits on a task barrier. (Non-Blocking)
 *
 * \param[in] barrier_ea	- ea of initialized barrier instance
 * \return
 *	MARS_SUCCESS		- barrier is released
 * \n	MARS_ERROR_NULL		- ea is 0
 * \n	MARS_ERROR_ALIGN	- ea not properly aligned
 * \n	MARS_ERROR_BUSY		- not all notifications arrived yet
 */
int mars_task_barrier_try_wait(uint64_t barrier_ea);

#if defined(__cplusplus)
}
#endif

#endif
